@@ -31,8 +31,8 @@ pub(super) fn generate_records(records: &MRecordTypes) -> TResult<Vec<TokenStrea
         let fields = prepare_field(record.fields.deref().iter(), records)?;
 
         let generated_record = quote! {
-            #[derive(Clone, Debug, fluence_test::internal::serde::Serialize, fluence_test::internal::serde::Deserialize)]
-            #[serde(crate = "fluence_test::internal::serde")]
+            #[derive(Clone, Debug, marine_rs_sdk_test::internal::serde::Serialize, marine_rs_sdk_test::internal::serde::Deserialize)]
+            #[serde(crate = "marine_rs_sdk_test::internal::serde")]
             pub struct #record_name_ident {
                 #(pub #fields),*
             }
